kfogel@collab.net wrote:
>
> Fixing now...
OK, that was expedient. Comparing with my effort, you caught a few places that I missed and vice versa. Attached is one patch for documentation (including comments within Emacs .el files) and one for the API function "svn_wc_resolve_conflict". The latter is separate because I'm not sure whether you skipped that change on purpose. You can choose to apply just "resolve-resolved-doc.diff" (deleting the seconf half of the log message) or both patches (using the full log message).
Log message (delete the second half if "resolve-resolved-api.diff" not applied):
[[[
Follow-up to r6597:
* doc/book/book/ch03.xml, doc/book/book/ch06.xml, doc/book/book/ch08.xml
* doc/book/book/appa.xml, doc/book/outline.txt
* doc/translations/french/client.texi, doc/user/svn-ref.tex
* tools/client-side/psvn/psvn.el, tools/client-side/vc-svn.el
The command is "resolved" now, not "resolve".
* subversion/include/svn_wc.h
* subversion/libsvn_wc/adm_crawler.c
* subversion/libsvn_wc/adm_ops.c
* subversion/libsvn_client/resolved.c
(svn_wc_resolved_conflict) Replaces svn_wc_resolve_conflict.
]]]
- Julian
Index: doc/translations/french/client.texi
===================================================================
--- doc/translations/french/client.texi (revision 6599)
+++ doc/translations/french/client.texi (working copy)
@@ -528,7 +528,7 @@
Une fois que vous avez résolu les conflits, vous devez en informer
Subversion en supprimant les trois fichiers tmp*. La commande
-@samp{svn resolve} est un racourçi qui ne fait rien sinon supprimer les
+@samp{svn resolved} est un racourçi qui ne fait rien sinon supprimer les
trois fichiers tmp* pour vous. Lorsque les fichiers tmp* sont supprimés
Subversion ne considère plus le fichier en état de conflit.
Index: doc/book/book/appa.xml
===================================================================
--- doc/book/book/appa.xml (revision 6599)
+++ doc/book/book/appa.xml (working copy)
@@ -365,7 +365,7 @@
<para>Subversion solves this problem by making conflicts more
tangible. It remembers that a file is in a state of conflict,
and won't allow you to commit your changes until you run
- <command>svn resolve</command>. See <xref
+ <command>svn resolved</command>. See <xref
linkend="svn-ch-3-sect-4.4"/> for more details.</para>
</sect1>
Index: doc/book/book/ch03.xml
===================================================================
--- doc/book/book/ch03.xml (revision 6599)
+++ doc/book/book/ch03.xml (working copy)
@@ -451,7 +451,7 @@
<para><command>svn merge</command></para>
</listitem>
<listitem>
- <para><command>svn resolve</command></para>
+ <para><command>svn resolved</command></para>
</listitem>
</itemizedlist>
</listitem>
@@ -1353,7 +1353,7 @@
</itemizedlist>
<para>Once you've resolved the conflict, you need to let
- Subversion know by running <command>svn resolve</command>.
+ Subversion know by running <command>svn resolved</command>.
This removes the three temporary files and Subversion no
longer considers the file to be in a state of
conflict.<footnote><para>You can always remove the temporary
@@ -1362,7 +1362,7 @@
</footnote></para>
<screen>
-$ svn resolve sandwich.txt
+$ svn resolved sandwich.txt
Resolved conflicted state of sandwich.txt
</screen>
@@ -1448,11 +1448,11 @@
Bottom piece of bread
</screen>
- <para>Now run <command>svn resolve</command> and you're now
+ <para>Now run <command>svn resolved</command> and you're now
ready to commit your changes:</para>
<screen>
-$ svn resolve sandwich.txt
+$ svn resolved sandwich.txt
$ svn commit -m "Go ahead and use my sandwich, discarding Sally's edits."
</screen>
@@ -1479,7 +1479,7 @@
$ ls sandwich.*
sandwich.txt sandwich.txt.mine sandwich.txt.r2 sandwich.txt.r1
$ cp sandwich.txt.r2 sandwich.txt
-$ svn resolve
+$ svn resolved
$ svn commit -m "Go ahead and use Sally's sandwich, discarding my edits."
</screen>
@@ -1500,15 +1500,15 @@
</screen>
<para>Note that when you revert a conflicted file, you don't
- have to run <command>svn resolve</command>.</para>
+ have to run <command>svn resolved</command>.</para>
</sect3>
<para>Now you're ready to check in your changes. Note that
- <command>svn resolve</command>, unlike most of the other
+ <command>svn resolved</command>, unlike most of the other
commands we've dealt with in this chapter, requires an
argument. In any case, you want to be careful and only run
- <command>svn resolve</command> when you're certain that you've
+ <command>svn resolved</command> when you're certain that you've
fixed the conflict in your file—once the temporary files
are removed, Subversion will let you commit the file even if
it still contains conflict markers.</para>
Index: doc/book/book/ch06.xml
===================================================================
--- doc/book/book/ch06.xml (revision 6599)
+++ doc/book/book/ch06.xml (working copy)
@@ -870,7 +870,7 @@
<para>To resolve property conflicts, simply ensure that the
conflicting properties contain the values that they should,
- and then use the <command>svn resolve</command> command to
+ and then use the <command>svn resolved</command> command to
alert Subversion that you have manually resolved the
problem.</para>
Index: doc/book/book/ch08.xml
===================================================================
--- doc/book/book/ch08.xml (revision 6599)
+++ doc/book/book/ch08.xml (working copy)
@@ -2716,7 +2716,7 @@
<para>Once you've resolved the conflict and
<filename>foo.c</filename> is ready to be committed, run
- <command>svn resolve</command> to let your working copy
+ <command>svn resolved</command> to let your working copy
know you've taken care of everything.</para>
<warning>
Index: doc/book/outline.txt
===================================================================
--- doc/book/outline.txt (revision 6599)
+++ doc/book/outline.txt (working copy)
@@ -42,7 +42,7 @@
a. svn update
b. make changes: edit directly, svn add, rm, cp, mv
c. examine changes: svn status, info, diff, revert
- d. resolve conflicts: svn up, resolve
+ d. resolve conflicts: svn up, resolved
e. svn commit
5. examining history: svn log, diff
Index: doc/user/svn-ref.tex
===================================================================
--- doc/user/svn-ref.tex (revision 6599)
+++ doc/user/svn-ref.tex (working copy)
@@ -98,7 +98,7 @@
revert {\sl targets} to ``pristine'' state \\
\\
-{\tt svn resolve} {\sl [targets\dots]} &
+{\tt svn resolved} {\sl [targets\dots]} &
removes conflict files associated with conflicted {\sl targets} \\
\\
Index: tools/client-side/psvn/psvn.el
===================================================================
--- tools/client-side/psvn/psvn.el (revision 6599)
+++ tools/client-side/psvn/psvn.el (working copy)
@@ -105,7 +105,7 @@
;; * proplist (plist, pl) implemented
;; * propset (pset, ps) used
;; * revert implemented
-;; * resolve
+;; * resolved
;; * status (stat, st) implemented
;; * switch (sw)
;; * update (up) implemented
Index: subversion/include/svn_wc.h
===================================================================
--- subversion/include/svn_wc.h (revision 6599)
+++ subversion/include/svn_wc.h (working copy)
@@ -1262,14 +1262,14 @@
* property conflict resolution was requested, and it was successful, then
* success gets reported.
*/
-svn_error_t *svn_wc_resolve_conflict (const char *path,
- svn_wc_adm_access_t *adm_access,
- svn_boolean_t resolve_text,
- svn_boolean_t resolve_props,
- svn_boolean_t recursive,
- svn_wc_notify_func_t notify_func,
- void *notify_baton,
- apr_pool_t *pool);
+svn_error_t *svn_wc_resolved_conflict (const char *path,
+ svn_wc_adm_access_t *adm_access,
+ svn_boolean_t resolve_text,
+ svn_boolean_t resolve_props,
+ svn_boolean_t recursive,
+ svn_wc_notify_func_t notify_func,
+ void *notify_baton,
+ apr_pool_t *pool);
/* Commits. */
Index: subversion/libsvn_wc/adm_crawler.c
===================================================================
--- subversion/libsvn_wc/adm_crawler.c (revision 6599)
+++ subversion/libsvn_wc/adm_crawler.c (working copy)
@@ -85,8 +85,8 @@
SVN_ERR (svn_wc__maybe_set_executable (NULL, file_path, adm_access, pool));
/* Remove any text conflict */
- SVN_ERR (svn_wc_resolve_conflict (file_path, adm_access, TRUE, FALSE, FALSE,
- NULL, NULL, pool));
+ SVN_ERR (svn_wc_resolved_conflict (file_path, adm_access, TRUE, FALSE, FALSE,
+ NULL, NULL, pool));
/* ### hey guys, shouldn't we recording the 'restored'
working-file's timestamp in its entry? Right now, every time we
Index: subversion/libsvn_wc/adm_ops.c
===================================================================
--- subversion/libsvn_wc/adm_ops.c (revision 6599)
+++ subversion/libsvn_wc/adm_ops.c (working copy)
@@ -2016,14 +2016,14 @@
/* The public function */
svn_error_t *
-svn_wc_resolve_conflict (const char *path,
- svn_wc_adm_access_t *adm_access,
- svn_boolean_t resolve_text,
- svn_boolean_t resolve_props,
- svn_boolean_t recursive,
- svn_wc_notify_func_t notify_func,
- void *notify_baton,
- apr_pool_t *pool)
+svn_wc_resolved_conflict (const char *path,
+ svn_wc_adm_access_t *adm_access,
+ svn_boolean_t resolve_text,
+ svn_boolean_t resolve_props,
+ svn_boolean_t recursive,
+ svn_wc_notify_func_t notify_func,
+ void *notify_baton,
+ apr_pool_t *pool)
{
struct resolve_callback_baton *baton = apr_pcalloc (pool, sizeof(*baton));
Index: subversion/libsvn_client/resolved.c
===================================================================
--- subversion/libsvn_client/resolved.c (revision 6599)
+++ subversion/libsvn_client/resolved.c (working copy)
@@ -45,8 +45,8 @@
SVN_ERR (svn_wc_adm_probe_open (&adm_access, NULL, path, TRUE, recursive,
pool));
- SVN_ERR (svn_wc_resolve_conflict (path, adm_access, TRUE, TRUE, recursive,
- ctx->notify_func, ctx->notify_baton, pool));
+ SVN_ERR (svn_wc_resolved_conflict (path, adm_access, TRUE, TRUE, recursive,
+ ctx->notify_func, ctx->notify_baton, pool));
SVN_ERR (svn_wc_adm_close (adm_access));
---------------------------------------------------------------------
To unsubscribe, e-mail: dev-unsubscribe@subversion.tigris.org
For additional commands, e-mail: dev-help@subversion.tigris.org
Received on Tue Jul 29 00:13:54 2003
Index: tools/client-side/vc-svn.el
===================================================================
--- tools/client-side/vc-svn.el (revision 6599)
+++ tools/client-side/vc-svn.el (working copy)
@@ -31,7 +31,7 @@
;;; web folder displays, or would it just languish in obscurity, the
;;; way CVS and RCS descriptions do?
;;;
;;; After manual merging, need some way to run `svn resolve'. Perhaps
;;; we should just prompt for approval when somebody tries to commit a
;;; conflicted file?
;;;
@@ -321,7 +321,7 @@
conflict markers into the file and leaves additional temporary files
containing the `ancestor', `mine', and `other' files.
-You may need to run `svn resolve' by hand once these conflicts have
+You may need to run `svn resolved' by hand once these conflicts have
been resolved.
Returns a vc status, which is used to determine whether conflicts need
@@ -31,7 +31,7 @@
;;; way CVS and RCS descriptions do?
;;;
-;;; After manual merging, need some way to run `svn resolve'. Perhaps
+;;; After manual merging, need some way to run `svn resolved'. Perhaps
;;; we should just prompt for approval when somebody tries to commit a
;;; conflicted file?